@@ -5,6 +5,9 @@ import warnings
 from urllib.parse import urlparse
 import re
 from bruteloops.db_manager import csv_split
+from bfg.breakers import (
+    ConnectionErrorBreakerProfile,
+    LockoutErrorBreakerProfile)
 from functools import wraps
 from random import randint
 from inspect import getargspec
@@ -59,10 +62,52 @@ def handleUA(f):
 
     return wrapper
 
+def append_or_naw(lst:list, cls:object, *args, **kwargs):
+    '''Append an instance of `cls` to `lst` if it doesn't already contain
+    one.
+
+    Args:
+      lst: List to check and append to.
+      cls: Class to check for.
+
+    Notes:
+      - Additional `*args` and `**kwargs` passed to this function are
+        used to initialize new instances of `cls`.
+      - This function mutates lst by appending instances of cls.
+    '''
+
+    # Check lst
+    for v in lst:
+        if isinstance(v, cls):
+            # naw...an instance already exists
+            return
+
+    # append
+    lst.append(cls(*args, **kwargs))
+
 class HTTPModule(Module):
 
     args = defaultHTTPArgs()
 
+    @classmethod
+    def build_interface(cls, *args, **kwargs):
+        '''Create standard breakers for HTTP modules.
+
+        Notes:
+          - Calls Module.build_interface after binding breaker
+            profiles.
+        '''
+
+        for klass in (
+                ConnectionErrorBreakerProfile,
+                LockoutErrorBreakerProfile,):
+
+            append_or_naw(
+                lst=cls.breaker_profiles,
+                cls=klass)
+
+        return super().build_interface(*args, **kwargs)
+
     def __init__(self, url, proxies, headers, verify_ssl, user_agent,
             allow_redirects, *args, **kwargs):
         '''Update the __init__ method of a class with a signature for common
